##  Step 1. Model SAP LeanIX Fact Sheets and Build Your Repository
How much pre-work needs to be done to start your transformation use case depends on your overall SAP LeanIX adoption. If your organization has been using SAP LeanIX already for some time, you might have a more or less complete inventory and view of your as-is architecture. If you are starting to use SAP LeanIX for your ERP transformation, you need to build that repository from scratch. This step is actually a classical Application Portfolio Assessment with SAP LeanIX, where we add some additional sub-steps (outlined below). Make sure to apply the best practices explained in the [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") use case guide, which gives you a detailed overview of how to build your foundation in SAP LeanIX, add key Fact Sheets, get data, e.g., via Surveys, and do your first assessment.
In this step, you should model the following Fact Sheet types in SAP LeanIX.
**Note**
A big undertaking like an ERP Transformation requires 100% reliability on data. Make use of SAP LeanIX [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.") to verify and gather data that is relevant to you, and use a [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal?locale=en-US&state=PRODUCTION&version=CLOUD "Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.") to ensure that you have all the information needed. Also, make sure that all Fact Sheets have clear ownership.
  * [Add Application Data to SAP LeanIX](https://help.sap.com/docs/leanix/ea/get-data-into-workspace?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a70da7a4410148292f7bd914f157b__step_1._upload_application_data_into_sap_leanix): It involves adding information about [Applications](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.") and their relevant attributes, such as relations/dependencies, lifecycles, Technical Fit, Functional Fit, Business Criticality, Organization (e.g., User Groups), and IT Components into the platform. This can be done via the [Excel Import/Export function](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file."), manual creation of Fact Sheets, or crowdsourcing via Surveys. Key mandatory attributes are:
    * Lifecycle
    * Business criticality (to ensure operational stability)
    * Functional / Technical Fit (to challenging status-quo / complexity reduction)
    * Subscription Roles - define employees from your organisation that are responsible for the application to provide further input (i.e. Application Owner)


**Tip**
If your organization uses SAP systems and services, the SAP landscape discovery feature can be used to discover your organization's SAP systems and services, both cloud and on-premise. To learn more, see [SAP Landscape Discovery](https://help.sap.com/docs/leanix/ea/sap-discovery-cloud-alm?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically discover and inventory SAP systems, services, and integration flows, ensuring an up-to-date overview of your SAP landscape.") .
  * [Add Business Capabilities](https://help.sap.com/docs/leanix/ea/get-data-into-workspace?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a70da7a4410148292f7bd914f157b__step_2._define_and_add_business_capabilities) and [link them to Applications](https://help.sap.com/docs/leanix/ea/get-data-into-workspace?locale=en-US&state=PRODUCTION&version=CLOUD "Getting initial data into SAP LeanIX workspace.") to show how your Applications support your organization's high-level activities and to scope your ERP transformation use case. Defining Business Capability properties such as responsible owner and Applications used can provide a better understanding of each capability's impact. Ensure your Business Capabilities are well-defined and communicated throughout the organization. Key mandatory attributes are:
    * Maturity (to understand how well they are supporting your Objectives to day vs. what the target maturity is)
    * Relations with Applications, Business Context (Processes) if applicable (see below), Objectives (can be linked once Objective Fact Sheet is created)
    * Gartner Pace Layering (can be applied using the Strategic Importance field in Business Capability Fact Sheets). To learn more, see [Pace Layering](https://help.sap.com/docs/leanix/ea/pace-layering?locale=en-US&state=PRODUCTION&version=CLOUD)
  * [Add Objectives](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model objectives. This includes best practices and applicable use cases, and common antipatterns.") that come from your business and link them to Business Capabilities and Organizations. Having Objectives will ensure that anything you plan in SAP LeanIX is aligned to/ supports the strategic goals of your organization. It will help you decide which Business Capabilities should be in scope for your transformation, and - vice versa - how the Business Capabilities in scope of your transformation will improve your organization’s objectives.
Both Business Capabilities and Objectives drive strategic thinking in your organization!
  * [Add Organization](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model organizations. This includes best practices and applicable use cases, and common antipatterns.") to get an understanding of the user base of your Applications and as a baseline for a phase-based ERP rollout.
  * [Add Interfaces](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model interfaces. This includes best practices and applicable use cases, and common antipatterns.") to get transparency of dependencies between different Applications and assess your current and future integration architecture. Add the following attributes:
    * Description
    * Data flow direction
    * Providing Application
    * Consuming Application
    * Frequency
    * Interface type
    * Relation with Data Objects
    * If applicable: Relations with IT Components to understand technical dependencies
  * [Add Business Context](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model business contexts. This includes best practices and applicable use cases, and common antipatterns.") (e.g., Processes) if your organization is process-driven. This will help you to gain a deep understanding of your business processes, align them with the IT landscape, trace impacts, improve processes through the transformation, make informed decisions, and foster collaboration among stakeholders. If your organization is using SAP Signavio, you can leverage the SAP LeanIX-[SAP Signavio out-of-the-box integration](https://help.sap.com/docs/leanix/ea/sap-signavio-integration?locale=en-US&state=PRODUCTION&version=CLOUD "The integration between SAP LeanIX and SAP Signavio enables seamless data synchronization, ensuring both systems have consistent and up-to-date information about business processes and IT systems. Learn how to set up the integration and how to map and sync data between SAP LeanIX and SAP Signavio.") to automate the process and synchronize information in both tools.


Overview of Fact Sheet types and relations that need to be modeled in this step:
![Relevant Fact Sheets for this step](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274703e47a4410148fbac3d10a6adc92_LowRes.jpg)
Fact Sheet types relevant for the Discovery phase of ERP Transformation
